@@ -25,7 +25,7 @@ import os
 import subprocess as sp
 
 __author__ = 'Niklas Rosenstein <rosensteinniklas@gmail.com>'
-__version__ = '0.1.2'
+__version__ = '0.1.4'
 
 Branch = collections.namedtuple('Branch', 'name,current')
 FileStatus = collections.namedtuple('FileStatus', 'mode,filename')
@@ -188,7 +188,7 @@ class Git:
     except sp.CalledProcessError:
       return None
 
-  def rev_list(rev: str, path: str = None) -> List[str]:
+  def rev_list(self, rev: str, path: str = None) -> List[str]:
     """
     Return a list of all Git revisions, optionally in the specified path.
     """
@@ -224,14 +224,32 @@ class Git:
       command += ['--orphan']
     sp.check_call(command, cwd=self.cwd)
 
-  def checkout(self, ref: str, quiet: bool = False):
+  def checkout(self, ref: str = None, files: List[str] = None, quiet: bool = False):
     """
-    Check out the specified ref.
+    Check out the specified ref or files.
     """
 
-    command = ['git', 'checkout', ref]
+    command = ['git', 'checkout']
+    if ref:
+      command += [ref]
     if quiet:
       command += ['-q']
+    if files:
+      command += ['--'] + files
+    sp.check_call(command, cwd=self.cwd)
+
+  def reset(self, ref: str = None, files: List[str] = None, hard: bool = False):
+    """
+    Reset to the specified ref or reset the files.
+    """
+
+    command = ['git', 'reset']
+    if ref:
+      command += [ref]
+    if quiet:
+      command += ['-q']
+    if files:
+      command += ['--'] + files
     sp.check_call(command, cwd=self.cwd)
 
   def get_commit_message(self, rev: str) -> str:
